---
title: CBR Content
---

# cbr-content
Repo to hold to content (multilingual) files for The Cyber Boardroom


## Repo details

![Current Release](https://img.shields.io/badge/release-v0.9.54-blue)

